@@ -6,6 +6,7 @@ from .post import Post
 from .team import Team, TeamMember
 from .user import User
 from .bot import PararamioBot
+from .activity import Activity, ActivityAction
 
 
 __all__ = (
@@ -18,4 +19,6 @@ __all__ = (
     'Team',
     'TeamMember',
     'PararamioBot',
+    'ActivityAction',
+    'Activity'
 )
