@@ -1,7 +1,11 @@
-from typing import Any, Callable, Dict, Iterable, List, Optional, Union
+from typing import Any, Callable, Dict, Iterable, List, Optional, Union, TYPE_CHECKING
 
 from pararamio.exceptions import PararamioRequestException
 from pararamio.utils import bot_request, join_ids, lazy_loader
+from pararamio.activity import Activity, ActivityAction
+
+if TYPE_CHECKING:
+    from datetime import datetime
 
 
 __all__ = ('PararamioBot',)
@@ -106,3 +110,22 @@ class PararamioBot:
 
     def get_user_by_id(self, user_id: int):
         return _one_or_value_error(lambda: self.get_users([user_id]), 'user with id {0} is not found', user_id)
+
+    def _user_activity_page_loader(self, user_id: int) -> Callable[..., Dict[str, Any]]:
+        def loader(action: ActivityAction = None, page: int = 1) -> Dict[str, Any]:
+            action_ = action.value if action else ''
+            url = f'/activity?user_id={user_id}&action={action_}&page={page}'
+            return self.request(url)
+
+        return loader
+
+    def get_user_activity(self, user_id: int, start: 'datetime', end: 'datetime', actions: List[ActivityAction] = None) -> List[Activity]:
+        """get user activity by user_id
+
+        :param user_id: user id
+        :param start: start time
+        :param end: end time
+        :param actions: list of action types (all actions if None)
+        :returns: activity list
+        """
+        return Activity.get_activity(self._user_activity_page_loader(user_id), start, end, actions)
